> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Heartrate 3 Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example on FT90
```
 #include <stdint.h>
 #include "heartrate_3.h"

// HeartRate 3 GPIO
sbit HR3_RST at GPIO_PIN1_bit;

void system_setup( void );
static void Interrupt_Setup( void );

void system_setup( void )
{
       //Local Declarations
     char            text[20] = { 0 };
     dynamic_modes_t dynamic_modes;
     uint8_t         address = 0x58;

        //Set up dynamic modes for Heart Rate 3 Initialization
     dynamic_modes.transmit = trans_dis;
     dynamic_modes.curr_range = led_double;
     dynamic_modes.adc_power = adc_on;
     dynamic_modes.clk_mode = osc_mode;
     dynamic_modes.tia_power = tia_off;
     dynamic_modes.rest_of_adc = rest_of_adc_off;
     dynamic_modes.afe_rx_mode = afe_rx_normal;
     dynamic_modes.afe_mode = afe_normal;

       //GPIO setup
     GPIO_Digital_Output(&GPIO_PORT_00_07, _GPIO_PINMASK_1 );

       //UART Initialize
     UART1_Init( 9600 );
     UART1_Write_Text( "UART is Initialized\r\n" );

       //Toggle Reset pin
     HR3_RST = 0;
     Delay_us(50);
     HR3_RST = 1;

       //I2C Initialize
     I2CM1_Init(_I2CM_SPEED_MODE_STANDARD, _I2CM_SWAP_DISABLE);
     UART1_Write_Text( "I2C Initialized\r\n" );

       //Heart Rate 3 Initialize
     hr3_init( address, &dynamic_modes );

}

void interrupt() iv IVT_GPIO_IRQ

{
   statHRMAlgo( hr3_get_led1_amb1_val() );
   //UART1_Write_Text( "Interrupt!\r\n" );
// Clear interrupt flag of PORT_24
  GPIO_INT_PEND24_bit = 1;
}


static void Interrupt_Setup( void )
{

// Enable digital input on PORT_00
  GPIO_Digital_Input(&GPIO_PORT_00_07,_GPIO_PINMASK_3);
// Enable all interrupts
  IRQ_CTRL.B31 = 0;
// Set rising edge to detect interrupt
  GPIO03_CFG0_bit = 1;
// Interrupt capable
  GPIO03_CFG1_bit = 1;
// Set GPIO direction as input
  GPIO03_CFG2_bit = 0;
  GPIO03_CFG3_bit = 0;
// Enable interrupt on PORT_3
  GPIO_INT_EN3_bit = 1;
  GLOBAL_INTERRUPT_MASK_BIT = 0;
}


```

```
void main()
{    //Local Declarations
     uint8_t i = 0;
     uint8_t rate = 0;
     uint32_t led1 = 0;
     char       text[15] = {0};
     char  uart_text[15] = {0};


     system_setup();     // GPIO / HeartRate 3 / UART / I2C Setups
     Delay_ms(200);

     initStatHRM();      // Initializes values to 0

     //InitTimerA();       // Initialize Timer
     //UART1_Write_Text("Start Counting\r\n");
     Interrupt_Setup();
      while(1)
      {
         rate = hr3_get_heartrate();                                    // Gets current Heartrate
         sprintl( uart_text, "HeartRate: %llu ", rate );                // Display Heartrate on UART
         UART1_Write_Text( uart_text );
         UART1_Write(13);
         UART1_Write(10);
       }
}

```

